@@ -20,22 +20,27 @@
 package builtin_test
 
 import (
+	"fmt"
+	"path/filepath"
+
 	. "gopkg.in/check.v1"
 
+	"github.com/snapcore/snapd/dirs"
 	"github.com/snapcore/snapd/interfaces"
 	"github.com/snapcore/snapd/interfaces/apparmor"
 	"github.com/snapcore/snapd/interfaces/builtin"
 	"github.com/snapcore/snapd/interfaces/mount"
 	"github.com/snapcore/snapd/snap"
 	"github.com/snapcore/snapd/snap/snaptest"
+	"github.com/snapcore/snapd/testutil"
 )
 
 type ContentSuite struct {
-	iface *builtin.ContentInterface
+	iface interfaces.Interface
 }
 
 var _ = Suite(&ContentSuite{
-	iface: &builtin.ContentInterface{},
+	iface: builtin.MustInterface("content"),
 })
 
 func (s *ContentSuite) TestName(c *C) {
@@ -193,13 +198,27 @@ apps:
 	c.Assert(err, ErrorMatches, "content plug must contain target path")
 }
 
+func (s *ContentSuite) TestSanitizeSlotNilAttrMap(c *C) {
+	const mockSnapYaml = `name: content-slot-snap
+version: 1.0
+apps:
+  foo:
+    command: foo
+    slots: [content]
+`
+	info := snaptest.MockInfo(c, mockSnapYaml, nil)
+	slot := &interfaces.Slot{SlotInfo: info.Slots["content"]}
+	err := s.iface.SanitizeSlot(slot)
+	c.Assert(err, ErrorMatches, "read or write path must be set")
+}
+
 func (s *ContentSuite) TestResolveSpecialVariable(c *C) {
 	info := snaptest.MockInfo(c, "name: name", &snap.SideInfo{Revision: snap.R(42)})
-	c.Check(builtin.ResolveSpecialVariable("foo", info), Equals, "/snap/name/42/foo")
-	c.Check(builtin.ResolveSpecialVariable("$SNAP/foo", info), Equals, "/snap/name/42/foo")
+	c.Check(builtin.ResolveSpecialVariable("foo", info), Equals, filepath.Join(dirs.CoreSnapMountDir, "name/42/foo"))
+	c.Check(builtin.ResolveSpecialVariable("$SNAP/foo", info), Equals, filepath.Join(dirs.CoreSnapMountDir, "name/42/foo"))
 	c.Check(builtin.ResolveSpecialVariable("$SNAP_DATA/foo", info), Equals, "/var/snap/name/42/foo")
 	c.Check(builtin.ResolveSpecialVariable("$SNAP_COMMON/foo", info), Equals, "/var/snap/name/common/foo")
-	c.Check(builtin.ResolveSpecialVariable("$SNAP", info), Equals, "/snap/name/42")
+	c.Check(builtin.ResolveSpecialVariable("$SNAP", info), Equals, filepath.Join(dirs.CoreSnapMountDir, "name/42"))
 	c.Check(builtin.ResolveSpecialVariable("$SNAP_DATA", info), Equals, "/var/snap/name/42")
 	c.Check(builtin.ResolveSpecialVariable("$SNAP_COMMON", info), Equals, "/var/snap/name/common")
 }
@@ -223,10 +242,10 @@ slots:
 	slot := &interfaces.Slot{SlotInfo: producerInfo.Slots["content"]}
 
 	spec := &mount.Specification{}
-	c.Assert(s.iface.MountConnectedPlug(spec, plug, slot), IsNil)
+	c.Assert(spec.AddConnectedPlug(s.iface, plug, nil, slot, nil), IsNil)
 	expectedMnt := []mount.Entry{{
-		Name:    "/snap/producer/5/export",
-		Dir:     "/snap/consumer/7/import",
+		Name:    filepath.Join(dirs.CoreSnapMountDir, "producer/5/export"),
+		Dir:     filepath.Join(dirs.CoreSnapMountDir, "consumer/7/import"),
 		Options: []string{"bind", "ro"},
 	}}
 	c.Assert(spec.MountEntries(), DeepEquals, expectedMnt)
@@ -254,24 +273,24 @@ slots:
 	slot := &interfaces.Slot{SlotInfo: producerInfo.Slots["content"]}
 
 	spec := &mount.Specification{}
-	c.Assert(s.iface.MountConnectedPlug(spec, plug, slot), IsNil)
+	c.Assert(spec.AddConnectedPlug(s.iface, plug, nil, slot, nil), IsNil)
 	expectedMnt := []mount.Entry{{
-		Name:    "/snap/producer/5/export",
-		Dir:     "/snap/consumer/7/import",
+		Name:    filepath.Join(dirs.CoreSnapMountDir, "producer/5/export"),
+		Dir:     filepath.Join(dirs.CoreSnapMountDir, "consumer/7/import"),
 		Options: []string{"bind", "ro"},
 	}}
 	c.Assert(spec.MountEntries(), DeepEquals, expectedMnt)
 
 	apparmorSpec := &apparmor.Specification{}
-	err := apparmorSpec.AddConnectedPlug(s.iface, plug, slot)
+	err := apparmorSpec.AddConnectedPlug(s.iface, plug, nil, slot, nil)
 	c.Assert(err, IsNil)
 	c.Assert(apparmorSpec.SecurityTags(), DeepEquals, []string{"snap.consumer.app"})
-	expected := `
+	expected := fmt.Sprintf(`
 # In addition to the bind mount, add any AppArmor rules so that
 # snaps may directly access the slot implementation's files
 # read-only.
-/snap/producer/5/export/** mrkix,
-`
+%s/producer/5/export/** mrkix,
+`, dirs.CoreSnapMountDir)
 	c.Assert(apparmorSpec.SnippetForTag("snap.consumer.app"), Equals, expected)
 }
 
@@ -297,7 +316,7 @@ slots:
 	slot := &interfaces.Slot{SlotInfo: producerInfo.Slots["content"]}
 
 	spec := &mount.Specification{}
-	c.Assert(s.iface.MountConnectedPlug(spec, plug, slot), IsNil)
+	c.Assert(spec.AddConnectedPlug(s.iface, plug, nil, slot, nil), IsNil)
 	expectedMnt := []mount.Entry{{
 		Name:    "/var/snap/producer/5/export",
 		Dir:     "/var/snap/consumer/7/import",
@@ -306,7 +325,7 @@ slots:
 	c.Assert(spec.MountEntries(), DeepEquals, expectedMnt)
 
 	apparmorSpec := &apparmor.Specification{}
-	err := apparmorSpec.AddConnectedPlug(s.iface, plug, slot)
+	err := apparmorSpec.AddConnectedPlug(s.iface, plug, nil, slot, nil)
 	c.Assert(err, IsNil)
 	c.Assert(apparmorSpec.SecurityTags(), DeepEquals, []string{"snap.consumer.app"})
 	expected := `
@@ -342,7 +361,7 @@ slots:
 	slot := &interfaces.Slot{SlotInfo: producerInfo.Slots["content"]}
 
 	spec := &mount.Specification{}
-	c.Assert(s.iface.MountConnectedPlug(spec, plug, slot), IsNil)
+	c.Assert(spec.AddConnectedPlug(s.iface, plug, nil, slot, nil), IsNil)
 	expectedMnt := []mount.Entry{{
 		Name:    "/var/snap/producer/common/export",
 		Dir:     "/var/snap/consumer/common/import",
@@ -351,7 +370,7 @@ slots:
 	c.Assert(spec.MountEntries(), DeepEquals, expectedMnt)
 
 	apparmorSpec := &apparmor.Specification{}
-	err := apparmorSpec.AddConnectedPlug(s.iface, plug, slot)
+	err := apparmorSpec.AddConnectedPlug(s.iface, plug, nil, slot, nil)
 	c.Assert(err, IsNil)
 	c.Assert(apparmorSpec.SecurityTags(), DeepEquals, []string{"snap.consumer.app"})
 	expected := `
@@ -364,3 +383,7 @@ slots:
 `
 	c.Assert(apparmorSpec.SnippetForTag("snap.consumer.app"), Equals, expected)
 }
+
+func (s *ContentSuite) TestInterfaces(c *C) {
+	c.Check(builtin.Interfaces(), testutil.DeepContains, s.iface)
+}
